
// Read the knobs routine for Euclidian math

void E_read_knobs()
{

  int Update; // loop to update EEPROM
  int UpdateB = 1;

  E_displayDelay --; // EEPROM write countdown

  // READ K KNOB
  kknob = EncodeReadK();
  if (kknob != 0 && time - last_read > read_delay) {
    if (channelbeats[active_channel][1] + kknob > channelbeats[active_channel][0]) {
      kknob = 0;
    }; // check within limits
    if (channelbeats[active_channel][1] + kknob < mink) {
      kknob = 0;
    };

    // CHECK AGAIN FOR LOGIC
    if (channelbeats[active_channel][1] > channelbeats[active_channel][0] - 1) {
      channelbeats[active_channel][1] = channelbeats[active_channel][0] - 1;
    };

    channelbeats[active_channel][1] = channelbeats[active_channel][1] + kknob; // update with encoder reading
    last_read = millis();
    changes = 1; // K change = 1
    E_displayDelay = displayDelay;
  }

  // READ N KNOB

  nknob = EncodeReadN();
  if (channelbeats[active_channel][0] > 16)
  {
    channelbeats[active_channel][0] = 16;
  };

  if (nknob != 0 && time - last_read > read_delay) {
    // Sense check n encoder reading to prevent crashes

    if (nn + nknob > maxn) {
      nknob = 0;
    }; // check below maxn
    if (nn + nknob < minn) {
      nknob = 0;
    }; // check above minn

    if (kk > nn + nknob - 1 && kk > 1) {// check if new n is lower than k + reduce K if it is
      channelbeats[active_channel][1] = channelbeats[active_channel][1] + nknob;
    };

    if (oo > nn + nknob - 1 && oo > 1) {// check if new n is lower than o + reduce o if it is
      channelbeats[active_channel][3] = channelbeats[active_channel][3] + nknob;
    };

    channelbeats[active_channel][0] = nn + nknob; // update with encoder reading
    kk = channelbeats[active_channel][1];
    nn = channelbeats[active_channel][0];  // update nn for ease of coding
    last_read = millis();
    changes = 2; // n change = 2
    E_displayDelay = displayDelay;
  }

  // READ O KNOB

  oknob = EncodeReadO();
  if (oknob != 0 && time - last_read > read_delay) {

    // Sense check o encoder reading to prevent crashes
    if (oo + oknob > channelbeats[active_channel][0]) {
      oknob = 0;
    }; // check below maxo
    if (oo + oknob < mino) {
      oknob = 0;
    }; // check above minn

    channelbeats[active_channel][3] = oo + oknob;
    oo = channelbeats[active_channel][3];  // update oo for ease of coding
    last_read = millis();
    changes = 3; // O change = 3
    E_displayDelay = displayDelay;

   /* Serial.println();
    Serial.print("oo = ");
    Serial.print(oo);
    Serial.println();
    */
  }

  // ------------------------------Euclidian EEPROM Write-----------------------------------

  // Save new Eulidian settings - saves when display countdown = 10 - reduces EEPROM writes
  // EEPROM.update() command wasn't working so a compare is done before writing.
  // Write is only done on a changed parameter

  if (E_displayDelay == 10) {

    for (Update = 0; Update < 3; Update++)
    {

      if (EEPROM.read(UpdateB) != channelbeats[Update][0]) {
        EEPROM.write((UpdateB), channelbeats[Update][0]); // write n
      }
      if (EEPROM.read(UpdateB + 1) != channelbeats[Update][1]) {
        EEPROM.write((UpdateB + 1), channelbeats[Update][1]); // write k
      }
      UpdateB = UpdateB + 2;
    }

    for (Update = 0; Update < 3; Update++)
    {
      if (EEPROM.read(Update + 7) != channelbeats[Update][3]) {
        EEPROM.write((Update + 7), channelbeats[Update][3]); // write o
      }
      if (EEPROM.read(Update + 10) != channelbeats[Update][4]) {
        EEPROM.write((Update + 10), channelbeats[Update][4]); // write whatever's in column 5
      }
    }
  }


  if (E_displayDelay < 2) {     // Euclidian EEPROM write timer
    E_displayDelay = 1;
  }
}

//END
